import os
from setuptools import find_packages, setup

CURRENT_FOLDER = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(CURRENT_FOLDER, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="nomoji",
    author="Valerio Maggio",
    version="0.0.2",
    author_email="vmaggio@anaconda.com",
    description="Silly Python Package to print digits using emojis",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/leriomaggio/emoji-numbers/",
    packages=find_packages(exclude=[]),
    include_package_data=True,
)



__version__ = "0.0.1"

KEYCAPS_DIGIT = "%d\uFE0F\u20E3"
KEYCAPS_TEN = "\u1F51F"
GAME_DIE = "🎲"

DIGITS = {n: (KEYCAPS_DIGIT % n) for n in range(10)}
DIGITS[10] = KEYCAPS_TEN


def emojize(number: int) -> str:
    """Convert any integer number into emoji digits"""

    try:
        number = abs(int(number))
    except ValueError as e:
        raise ValueError("Only integer numbers could be emojized")
    else:
        if number in range(0, 9):
            return DIGITS[number]
        return " ".join([DIGITS[int(d)] for d in str(number)])



import pytest
from nomoji import DIGITS, GAME_DIE
from nomoji import emojize


def test_game_die():
    assert GAME_DIE == "🎲"


def test_all_digits():
    assert len(DIGITS) == 11, "Not all numbers in Digits"
    assert all(k in range(0, 11) for k in DIGITS)


def test_emojize_on_non_numbers_raises_exception():
    with pytest.raises(ValueError):
        emojize("non number")


def test_emojize_on_numbers_as_strings():
    assert emojize("2") == DIGITS[2]
    assert emojize("4") == DIGITS[4]
    assert emojize("24") == f"{DIGITS[2]} {DIGITS[4]}"


def test_emojize_on_float_numbers():
    assert emojize(1.3) == DIGITS[1]


def test_emojize_on_negative_ints():
    assert emojize(-9) == DIGITS[9]
